#!/usr/bin/python
# -*- coding: utf-8 -*-

from datetime import datetime

from bson import Binary
from celery.backends.mongodb import MongoBackend


__all__ = ['MongoCustomBackend']


class MongoCustomBackend(MongoBackend):

    def _store_result(self, task_id, result, status, traceback=None, request=None, **kwargs):
        """Store return value and status of an executed task."""
        meta = {'_id': task_id,
                'task_name': request.task if request else None,
                'status': status,
                'result': str(result),
                'date_done': datetime.now(),
                'args': request.args if request else None,
                'traceback': str(traceback),
                'children': Binary(self.encode(self.current_task_children(request), )),
                }
        self.collection.save(meta)

        return result

    def _save_group(self, group_id, result):
        """Save the group result."""
        meta = {
            '_id': group_id,
            'result': [{'id': i.id, 'status': i.status, 'result': i.result} for i in result.results],
            'date_done': datetime.now()
        }
        self.collection.save(meta)

        return result



#!/usr/bin/python
# -*- coding: utf-8 -*-

from setuptools import setup, find_packages

PACKAGE = "mycelery"
NAME = "mycelery"
DESCRIPTION = "For mycelery! For Tim"
AUTHOR = "Lei wenzheng"
AUTHOR_EMAIL = "leiwz@kaisagroup.com"
URL = "https://github.com/leiwenzheng/mycelery.git"
VERSION = __import__(PACKAGE).__version__

setup(
    name=NAME,
    version=VERSION,
    description=DESCRIPTION,
    author=AUTHOR,
    author_email=AUTHOR_EMAIL,
    license="Apache License, Version 2.0",
    url=URL,
    packages=find_packages(),
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
    ],
    entry_points={
        'console_scripts': []
    },
    zip_safe=False,
    install_requires=['pymongo>=3.4.0']
)

